@@ -2,5 +2,5 @@ from django.apps import AppConfig
 
 
 class OSMFieldConfig(AppConfig):
-    name = 'osm_field'
-    verbose_name = 'OSM Field'
+    name = "osm_field"
+    verbose_name = "OSM Field"
